# Youtube Autonomous Youtube API module

The API to connect with the Youtube platform.

This library will interact with Youtube by
using its v3 Data service.

It will create a `client-secret.json` file
and a `token_files` folder in the root
folder of the project in which you are
implementing and using this library.